# Summary

[Introduction](index.md)

# Getting Started

- [Setup with Claude Code](setup.md)

# Commands

- [Overview](commands/overview.md)
- [inspect](commands/inspect.md)
- [find](commands/find.md)
- [interactive](commands/interactive.md)
- [hover](commands/hover.md)
- [definition](commands/definition.md)
- [references](commands/references.md)
- [workspace-symbols](commands/workspace-symbols.md)
- [document-symbols](commands/document-symbols.md)
- [daemon](commands/daemon.md)

# Reference

- [Performance](performance.md)
- [Troubleshooting](troubleshooting.md)
